/*************** Includes *****************************************************************************************/
#include "system.h"
#include "pin_manager.h"

void PIN_MANAGER_Initialize(void)
{
    LATA = 0b00110000;              // /ALARM & /STOP HIGH
    LATB = 0b00000000;
    LATC = 0b00000011;              // RS & R/W HIGH
    ANSELA = 0x00;
    ANSELB = 0x00;
    ANSELC = 0x00;
    //WPUA = 0x00;
    WPUA = 0x03;                    // enable weak pullups for key inputs
    WPUB = 0xF0;                    // Weak pullups for opto inputs
    WPUC = 0x00;
    TRISA = 0b11001111;
    TRISB = 0b11111111;
    TRISC = 0b00000000;

    OPTION_REGbits.nWPUEN = 0;      // enable weak pullups
    OPTION_REGbits.INTEDG = 1;      // enable positive INT edge
    APFCON1 = 0x00;
    APFCON0 = 0x00;
    
    // interrupt on change for group IOCAF - clear interrupt flag bit
    IOCAFbits.IOCAF0 = 0; // Pin : RA0
    IOCAFbits.IOCAF1 = 0; // Pin : RA1

    // interrupt on change for group IOCAN - enable negative edge triggers
    IOCANbits.IOCAN0 = 1; // Pin : RA0
    IOCANbits.IOCAN1 = 1; // Pin : RA1

    INTCONbits.INTE = 1;    // Enable INT interrupt
    INTCONbits.IOCIE = 1;   // Enable IOC interrupts
}

void PIN_MANAGER_IOC(void)
{    
    // interrupt on change for group IOCAF
    if(IOCAFbits.IOCAF0 == 1)
    {
        IOCAF0_ISR();            
    }
    if(IOCAFbits.IOCAF1 == 1)
    {
        IOCAF1_ISR();            
    }
}

/**
   IOCAF0 Interrupt Service Routine
*/
void IOCAF0_ISR(void) 
{

    // Add custom IOCAF0 code
    if(IOCAF0_InterruptHandler)
    {
        IOCAF0_InterruptHandler();
    }
    IOCAFbits.IOCAF0 = 0;
}

/**
  Allows selecting an interrupt handler for IOCAF0 at application runtime
*/
void IOCAF0_SetInterruptHandler(void* InterruptHandler)
{
    IOCAF0_InterruptHandler = InterruptHandler;
}

/**
   IOCAF1 Interrupt Service Routine
*/
void IOCAF1_ISR(void) 
{

    // Add custom IOCAF1 code
    if(IOCAF1_InterruptHandler)
    {
        IOCAF1_InterruptHandler();
    }
    IOCAFbits.IOCAF1 = 0;
}

/**
  Allows selecting an interrupt handler for IOCAF1 at application runtime
*/
void IOCAF1_SetInterruptHandler(void* InterruptHandler)
{
    IOCAF1_InterruptHandler = InterruptHandler;
}
/*************** End of File **************************************************************************************/