/**
  TMR1 Generated Driver API Header File
  @Company    Microchip Technology Inc.
  @File Name    tmr1.h
  @Summary    This is the generated header file for the TMR1 driver using MPLAB(c) Code Configurator
  @Description
    This header file provides APIs for driver for TMR1.
    Generation Information :
        Product Revision  :  MPLAB(c) Code Configurator - 3.16
        Device            :  PIC16F1829
        Driver Version    :  2.00
    The generated drivers are tested against the following:
        Compiler          :  XC8 1.35
        MPLAB             :  MPLAB X 3.20
*/

#ifndef _TMR1_H
#define _TMR1_H

/*************** Includes *****************************************************************************************/
#include <stdbool.h>
#include <stdint.h>

#ifdef __cplusplus  // Provide C++ Compatibility

    extern "C" {

#endif

#define TMR1_INTERRUPT_TICKER_FACTOR    10

/**
  Section: TMR1 APIs
*/

/**
  @Summary    Initializes the TMR1
  @Description
    This routine initializes the TMR1.
    This routine must be called before any other TMR1 routine is called.
    This routine should only be called once during system initialization.
  @Example
    <code>
    main()
    {
        // Initialize TMR1 module
        TMR1_Initialize();

        // Do something else...
    }
    </code>
*/
void TMR1_Initialize(void);

/**
  @Summary    This function starts the TMR1.
  @Description
    This function starts the TMR1 operation.
    This function must be called after the initialization of TMR1.
  @Preconditions    Initialize  the TMR1 before calling this function.
  @Example
    <code>
    // Initialize TMR1 module

    // Start TMR1
    TMR1_StartTimer();

    // Do something else...
    </code>
*/
void TMR1_StartTimer(void);

/**
  @Summary    This function stops the TMR1.
  @Description
    This function stops the TMR1 operation.
    This function must be called after the start of TMR1.
  @Preconditions    Initialize  the TMR1 before calling this function.
  @Example
    <code>
    // Initialize TMR1 module

    // Start TMR1
    TMR1_StartTimer();

    // Do something else...

    // Stop TMR1;
    TMR1_StopTimer();
    </code>
*/
void TMR1_StopTimer(void);

/**
  @Summary    Timer Interrupt Service Routine
  @Description    Timer Interrupt Service Routine is called by the Interrupt Manager.
  @Preconditions    Initialize  the TMR1 module with interrupt before calling this ISR.
*/
void TMR1_ISR(void);

/**
  @Summary    CallBack function.
  @Description  This routine is called by the TMR1_ISR when TMR1 has interrupted TMR1_INTERRUPT_TICKER_FACTOR times
  @Preconditions  Initialize  the TMR1 module with interrupt before calling this function.
*/
void TMR1_CallBack(void);

/**
  @Summary    Set Timer Interrupt Handler
  @Description    This sets the function to be called during the ISR
  @Preconditions  Initialize  the TMR1 module with interrupt before calling this.
  @Param    Address of function to be set
*/
 void TMR1_SetInterruptHandler(void *InterruptHandler);

/**
  @Summary    Timer Interrupt Handler
  @Description    This is a function pointer to the function that will be called during the ISR
  @Preconditions  Initialize  the TMR1 module with interrupt before calling this isr.
*/
void (*TMR1_InterruptHandler)(void);

/**
  @Summary    Default Timer Interrupt Handler
  @Description    This is the default Interrupt Handler function
  @Preconditions  Initialize  the TMR1 module with interrupt before calling this isr.
*/
void TMR1_DefaultInterruptHandler(void);

#ifdef __cplusplus  // Provide C++ Compatibility

    }

#endif

#endif // _TMR1_H
/*************** End of File **************************************************************************************/